# Changelog

All notable changes to this project will be documented in this file.

## [0.5.0] - 2025-11-07

### 🚀 Features

- impl qbt_tracker.py with qbittorrent-api

### 📚 Documentation

- impl docstrings on all cmd
- update README.md

### ⚙️ Miscellaneous Tasks

- fix uv build on test-pypi
- fix and improvement
- impl AGENTS.md
- uv sync -U
- add mypy type checker
- give up directory glob on date-rename
- give up directory glob on iconv8
- rename some commands
- uv add qbittorrent-api
- bump version

## [0.4.0] - 2025-11-01

### 🚀 Features

- impl TarFileZstd on tarfile.py
- impl .zst support on deb_extract.py
- impl apt_lists.py
- impl iconv-utf8 cmd
- impl --gitignore option on iconv-utf8
- impl src/chaos_box/cmd/prime.py
- impl src/chaos_box/utils.py

### 🚜 Refactor

- remove logging_config and impl JsonFormatter

### 🧪 Testing

- impl test cases on gitignore.py
- impl test cases on tarfile.py
- enable tests session on noxfile.py

### ⚙️ Miscellaneous Tasks

- fixup README.md
- fixup qrcode_split.py
- impl helper func on gitignore.py
- impl respect gitignore on rename_with_date.py
- enrich classifiers and keywords
- remove exec mode on cmd/qbt_*.py
- impl sorted_repo_stats on apt_lists.py
- toml format on pyproject.toml
- skip utf-8 encoded files
- impl output_dir on iconv-utf8
- impl skipped_files and --force option on iconv-utf8
- convert logfile to bool on setup_logger
- update deep_merge on utils.py
- update .gitignore
- migrate pdm to uv
- migrate utils into chaos-utils

## [0.3.2] - 2025-06-16

### 🚜 Refactor

- keep using python-debian on deb_extract.py

### ⚙️ Miscellaneous Tasks

- bump version

## [0.3.1] - 2025-06-16

### 🚜 Refactor

- use unix-ar instead of debian.arfile (python3-debian) on deb_extract.py

### 📚 Documentation

- fixup README.md

### ⚙️ Miscellaneous Tasks

- bump version

## [0.3.0] - 2025-06-15

### 🚀 Features

- impl respect-gitignore option on shasum_list.py
- migrate qbt_dump.py
- migrate qbt_migrate.py
- migrate qrcode_split.py
- migrate qrcode_merge.py

### 📚 Documentation

- enrich README.md

### ⚙️ Miscellaneous Tasks

- update pyproject.toml
- rename net_stats.py to netstats.py
- change file_path format and default value on rotate_images.py
- split _extract_ar_member() on deb_extract.py
- avoid f-string on logger
- relocate cmd files
- rename punc_conv.py to pconv.py
- remove some stupid tool from project.scripts
- update dependencies on pyproject.toml
- fixup archive_mobi.py
- fixup archive_dirs.py
- fixup shasum_list.py
- fixup qrcode_split.py
- fixup qrcode_merge.py
- fixup qbt_dump.py
- fixup qbt_migrate.py
- PyPI package rename to chaos-box
- bump version

## [0.2.0] - 2025-06-12

### 🚀 Features

- implement rename_with_date.py
- implement shasum_list.py

### 📚 Documentation

- implement README.md

### ⚙️ Miscellaneous Tasks

- set console log to brief format
- update pyproject.toml
- rename tests.yaml to nox.yaml
- use pypa/gh-action-pypi-publish
- add missing MIT LICENSE
- bump version

## [0.1.0] - 2025-06-12

### 🚀 Features

- migrate sort_keys.py
- migrate urlencode.py
- migrate net_stats.py
- migrate dir_archive.py
- migrate merge_ip_ranges.py
- migrate mobi_archive.py
- migrate enc_recover.py
- migrate punc_conv.py
- migrate deb_extract.py
- migrate pascal.py
- migrate rotate_images.py

### 🧪 Testing

- disable nox tests session

### ⚙️ Miscellaneous Tasks

- init commit
- add dependencies
- add publish-to-test-pypi.yaml
- bump version

<!-- generated by git-cliff -->
